=====
Usage
=====

To use Search Analysis in a project::

 import search_analysis


.. py:module:: search_analysis

Evaluation Object
-----------------

.. autoclass:: EvaluationObject
   :members:


Comparison Tool
-----------------

.. autoclass:: ComparisonTool
   :members:
